package cloudduggu.com;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.server.ResponseStatusException;

/**
 * Provides upload, download, view endpoints for spark & client system.
 *
 * @author  Sarvesh Kumar (CloudDuggu.com)
 * @version 1.0
 * @since   2020-07-25
 */

@RestController
public class UploadDownloadController {

	private static final Logger logger = LoggerFactory.getLogger(UploadDownloadController.class);

	static StringBuilder data = new StringBuilder();
	static StringBuilder queryString = new StringBuilder();

//	download files from client system
	@GetMapping("/download/{fileName:.+}")
	public ResponseEntity downloadFileFromLocal(@PathVariable String fileName) {
//		Path path = Paths.get(dataIn + fileName);
		Resource resource = null;
		try {
//			resource = new UrlResource(path.toUri());
			logger.info("DownloadFile: {}", fileName);
			resource = new ClassPathResource("classpath:data/"+fileName);

		} catch (Exception e) {
			logger.error(e.getMessage());
		}
		return ResponseEntity.ok()
//				.contentType(MediaType.parseMediaType("application/csv"))
				.header(HttpHeaders.CONTENT_DISPOSITION, "attachment; filename=\"" + resource.getFilename() + "\"")
				.body(resource);
	}

//	upload content into client system
	@PostMapping("/upload")
	public void upload(@RequestParam String result) {
		try{
			logger.info("result-> "+result);
			data.append(result);
		}catch(Exception ioe){
			logger.error(ioe.getMessage());
		}
	}

//	view result data content from memory object
	@GetMapping("/data")
	public String getData() {
		return data.toString();
	}

//	delete result data content from memory object
	@GetMapping("/deleteData")
	public void deleteData() {
		data.delete(0, data.length());
	}


//	add request query into memory object
	@GetMapping("/addQuery")
	public void addQuery(@RequestParam String query) {
		logger.info("Add Query: "+query);
		queryString.delete(0, queryString.length());
		queryString.append(query);
	}

//	get request query from memory object
	@GetMapping("/getQuery")
	public String getQuery() {
		logger.info("Get Query.");
		if(queryString.length() > 1)
			return queryString.toString();
		else
			throw new ResponseStatusException(HttpStatus.NOT_FOUND, "Query Not Found");

	}

//	delete request query from memory object
	@GetMapping("/deleteQuery")
	public void deleteQuery() {
		logger.info("Delete Query.");
		queryString.delete(0, queryString.length());
	}

}